@@ -60,14 +60,14 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_iam
-import aws_cdk.core
-import constructs
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_940a1ce0
+import aws_cdk.core as _aws_cdk_core_f4b25747
+import constructs as _constructs_77d1e7e8
 
 
-@jsii.implements(aws_cdk.core.IInspectable)
+@jsii.implements(_aws_cdk_core_f4b25747.IInspectable)
 class CfnProfilingGroup(
-    aws_cdk.core.CfnResource,
+    _aws_cdk_core_f4b25747.CfnResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-codeguruprofiler.CfnProfilingGroup",
 ):
@@ -108,14 +108,14 @@ class CfnProfilingGroup(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: _aws_cdk_core_f4b25747.Construct,
         id: builtins.str,
         *,
         profiling_group_name: builtins.str,
         agent_permissions: typing.Any = None,
-        anomaly_detection_notification_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, typing.Union["CfnProfilingGroup.ChannelProperty", typing.Dict[str, typing.Any]]]]]] = None,
+        anomaly_detection_notification_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnProfilingGroup.ChannelProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
         compute_platform: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.core.CfnTag, typing.Dict[str, typing.Any]]]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''Create a new ``AWS::CodeGuruProfiler::ProfilingGroup``.
 
@@ -128,18 +128,7 @@ class CfnProfilingGroup(
         :param tags: A list of tags to add to the created profiling group.
         '''
         if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                id: builtins.str,
-                *,
-                profiling_group_name: builtins.str,
-                agent_permissions: typing.Any = None,
-                anomaly_detection_notification_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, typing.Union[CfnProfilingGroup.ChannelProperty, typing.Dict[str, typing.Any]]]]]] = None,
-                compute_platform: typing.Optional[builtins.str] = None,
-                tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.core.CfnTag, typing.Dict[str, typing.Any]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f716c140051ab3ab0d85b12915727069b195d1b8b90a71c09337bd86eed52c55)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnProfilingGroupProps(
@@ -153,15 +142,13 @@ class CfnProfilingGroup(
         jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
-    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+    def inspect(self, inspector: _aws_cdk_core_f4b25747.TreeInspector) -> None:
         '''Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
         '''
         if __debug__:
-            def stub(inspector: aws_cdk.core.TreeInspector) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__cd8d9915cd249d32e2cca82629c4798ab6b6578ff7e101f1d0fe197015130b43)
             check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
@@ -174,9 +161,7 @@ class CfnProfilingGroup(
         :param props: -
         '''
         if __debug__:
-            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__b9120857a7ca75673ab928dc634fc0ff341c0a256d3f8e97da5d3d1c50c868af)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -202,12 +187,12 @@ class CfnProfilingGroup(
 
     @builtins.property
     @jsii.member(jsii_name="tags")
-    def tags(self) -> aws_cdk.core.TagManager:
+    def tags(self) -> _aws_cdk_core_f4b25747.TagManager:
         '''A list of tags to add to the created profiling group.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-tags
         '''
-        return typing.cast(aws_cdk.core.TagManager, jsii.get(self, "tags"))
+        return typing.cast(_aws_cdk_core_f4b25747.TagManager, jsii.get(self, "tags"))
 
     @builtins.property
     @jsii.member(jsii_name="agentPermissions")
@@ -227,9 +212,7 @@ class CfnProfilingGroup(
     @agent_permissions.setter
     def agent_permissions(self, value: typing.Any) -> None:
         if __debug__:
-            def stub(value: typing.Any) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__2b8f16257dd8b97675d05722f4c74a89415dfe9dd90c9c69acfa5fb72268e9e3)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "agentPermissions", value)
 
@@ -245,9 +228,7 @@ class CfnProfilingGroup(
     @profiling_group_name.setter
     def profiling_group_name(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__827c37a5bbd608aa0ab6c3cd91c24b907ebc73319417390b0a1c6656740f2bb4)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "profilingGroupName", value)
 
@@ -255,24 +236,20 @@ class CfnProfilingGroup(
     @jsii.member(jsii_name="anomalyDetectionNotificationConfiguration")
     def anomaly_detection_notification_configuration(
         self,
-    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnProfilingGroup.ChannelProperty"]]]]:
+    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnProfilingGroup.ChannelProperty"]]]]:
         '''Adds anomaly notifications for a profiling group.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-anomalydetectionnotificationconfiguration
         '''
-        return typing.cast(typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnProfilingGroup.ChannelProperty"]]]], jsii.get(self, "anomalyDetectionNotificationConfiguration"))
+        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnProfilingGroup.ChannelProperty"]]]], jsii.get(self, "anomalyDetectionNotificationConfiguration"))
 
     @anomaly_detection_notification_configuration.setter
     def anomaly_detection_notification_configuration(
         self,
-        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnProfilingGroup.ChannelProperty"]]]],
+        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnProfilingGroup.ChannelProperty"]]]],
     ) -> None:
         if __debug__:
-            def stub(
-                value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnProfilingGroup.ChannelProperty]]]],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__9a8dbd2729ce0a37f9a95dcd047bc3c7c6bbbe1f281e0cefa1ec7a889ad8ac9b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "anomalyDetectionNotificationConfiguration", value)
 
@@ -290,12 +267,61 @@ class CfnProfilingGroup(
     @compute_platform.setter
     def compute_platform(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__54bdaa4e19c8380cabfc1afb202043849692b396db8548d3f7e55cd3ce85d369)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "computePlatform", value)
 
+    @jsii.data_type(
+        jsii_type="@aws-cdk/aws-codeguruprofiler.CfnProfilingGroup.AgentPermissionsProperty",
+        jsii_struct_bases=[],
+        name_mapping={"principals": "principals"},
+    )
+    class AgentPermissionsProperty:
+        def __init__(self, *, principals: typing.Sequence[builtins.str]) -> None:
+            '''
+            :param principals: ``CfnProfilingGroup.AgentPermissionsProperty.Principals``.
+
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codeguruprofiler-profilinggroup-agentpermissions.html
+            :exampleMetadata: fixture=_generated
+
+            Example::
+
+                # The code below shows an example of how to instantiate this type.
+                # The values are placeholders you should change.
+                import aws_cdk.aws_codeguruprofiler as codeguruprofiler
+                
+                agent_permissions_property = codeguruprofiler.CfnProfilingGroup.AgentPermissionsProperty(
+                    principals=["principals"]
+                )
+            '''
+            if __debug__:
+                type_hints = typing.get_type_hints(_typecheckingstub__30fe6ae1b3b847041e02a0703afa10fbbab3170e1df4694345a7ef3fdd5b28df)
+                check_type(argname="argument principals", value=principals, expected_type=type_hints["principals"])
+            self._values: typing.Dict[builtins.str, typing.Any] = {
+                "principals": principals,
+            }
+
+        @builtins.property
+        def principals(self) -> typing.List[builtins.str]:
+            '''``CfnProfilingGroup.AgentPermissionsProperty.Principals``.
+
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codeguruprofiler-profilinggroup-agentpermissions.html#cfn-codeguruprofiler-profilinggroup-agentpermissions-principals
+            '''
+            result = self._values.get("principals")
+            assert result is not None, "Required property 'principals' is missing"
+            return typing.cast(typing.List[builtins.str], result)
+
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return "AgentPermissionsProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
+
     @jsii.data_type(
         jsii_type="@aws-cdk/aws-codeguruprofiler.CfnProfilingGroup.ChannelProperty",
         jsii_struct_bases=[],
@@ -332,16 +358,10 @@ class CfnProfilingGroup(
                 )
             '''
             if __debug__:
-                def stub(
-                    *,
-                    channel_uri: builtins.str,
-                    channel_id: typing.Optional[builtins.str] = None,
-                ) -> None:
-                    ...
-                type_hints = typing.get_type_hints(stub)
+                type_hints = typing.get_type_hints(_typecheckingstub__5a6c20a5deea4cd71b89d6e657354d122cbb4a3334b43d004333284d685373ea)
                 check_type(argname="argument channel_uri", value=channel_uri, expected_type=type_hints["channel_uri"])
                 check_type(argname="argument channel_id", value=channel_id, expected_type=type_hints["channel_id"])
-            self._values: typing.Dict[str, typing.Any] = {
+            self._values: typing.Dict[builtins.str, typing.Any] = {
                 "channel_uri": channel_uri,
             }
             if channel_id is not None:
@@ -395,9 +415,9 @@ class CfnProfilingGroupProps:
         *,
         profiling_group_name: builtins.str,
         agent_permissions: typing.Any = None,
-        anomaly_detection_notification_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, typing.Union[CfnProfilingGroup.ChannelProperty, typing.Dict[str, typing.Any]]]]]] = None,
+        anomaly_detection_notification_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnProfilingGroup.ChannelProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
         compute_platform: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.core.CfnTag, typing.Dict[str, typing.Any]]]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''Properties for defining a ``CfnProfilingGroup``.
 
@@ -437,22 +457,13 @@ class CfnProfilingGroupProps:
             )
         '''
         if __debug__:
-            def stub(
-                *,
-                profiling_group_name: builtins.str,
-                agent_permissions: typing.Any = None,
-                anomaly_detection_notification_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, typing.Union[CfnProfilingGroup.ChannelProperty, typing.Dict[str, typing.Any]]]]]] = None,
-                compute_platform: typing.Optional[builtins.str] = None,
-                tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.core.CfnTag, typing.Dict[str, typing.Any]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__d7ab3f016dc6dd9dc09dbdd386c1dc4b0b32d9e05d5f91674f86042fc33b91f7)
             check_type(argname="argument profiling_group_name", value=profiling_group_name, expected_type=type_hints["profiling_group_name"])
             check_type(argname="argument agent_permissions", value=agent_permissions, expected_type=type_hints["agent_permissions"])
             check_type(argname="argument anomaly_detection_notification_configuration", value=anomaly_detection_notification_configuration, expected_type=type_hints["anomaly_detection_notification_configuration"])
             check_type(argname="argument compute_platform", value=compute_platform, expected_type=type_hints["compute_platform"])
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "profiling_group_name": profiling_group_name,
         }
         if agent_permissions is not None:
@@ -492,13 +503,13 @@ class CfnProfilingGroupProps:
     @builtins.property
     def anomaly_detection_notification_configuration(
         self,
-    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnProfilingGroup.ChannelProperty]]]]:
+    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnProfilingGroup.ChannelProperty]]]]:
         '''Adds anomaly notifications for a profiling group.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-anomalydetectionnotificationconfiguration
         '''
         result = self._values.get("anomaly_detection_notification_configuration")
-        return typing.cast(typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnProfilingGroup.ChannelProperty]]]], result)
+        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnProfilingGroup.ChannelProperty]]]], result)
 
     @builtins.property
     def compute_platform(self) -> typing.Optional[builtins.str]:
@@ -512,13 +523,13 @@ class CfnProfilingGroupProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def tags(self) -> typing.Optional[typing.List[aws_cdk.core.CfnTag]]:
+    def tags(self) -> typing.Optional[typing.List[_aws_cdk_core_f4b25747.CfnTag]]:
         '''A list of tags to add to the created profiling group.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-tags
         '''
         result = self._values.get("tags")
-        return typing.cast(typing.Optional[typing.List[aws_cdk.core.CfnTag]], result)
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_core_f4b25747.CfnTag]], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -552,7 +563,7 @@ class ComputePlatform(enum.Enum):
 
 
 @jsii.interface(jsii_type="@aws-cdk/aws-codeguruprofiler.IProfilingGroup")
-class IProfilingGroup(aws_cdk.core.IResource, typing_extensions.Protocol):
+class IProfilingGroup(_aws_cdk_core_f4b25747.IResource, typing_extensions.Protocol):
     '''IResource represents a Profiling Group.'''
 
     @builtins.property
@@ -567,8 +578,8 @@ class IProfilingGroup(aws_cdk.core.IResource, typing_extensions.Protocol):
     @jsii.member(jsii_name="grantPublish")
     def grant_publish(
         self,
-        grantee: aws_cdk.aws_iam.IGrantable,
-    ) -> aws_cdk.aws_iam.Grant:
+        grantee: _aws_cdk_aws_iam_940a1ce0.IGrantable,
+    ) -> _aws_cdk_aws_iam_940a1ce0.Grant:
         '''Grant access to publish profiling information to the Profiling Group to the given identity.
 
         This will grant the following permissions:
@@ -581,7 +592,10 @@ class IProfilingGroup(aws_cdk.core.IResource, typing_extensions.Protocol):
         ...
 
     @jsii.member(jsii_name="grantRead")
-    def grant_read(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
+    def grant_read(
+        self,
+        grantee: _aws_cdk_aws_iam_940a1ce0.IGrantable,
+    ) -> _aws_cdk_aws_iam_940a1ce0.Grant:
         '''Grant access to read profiling information from the Profiling Group to the given identity.
 
         This will grant the following permissions:
@@ -595,7 +609,7 @@ class IProfilingGroup(aws_cdk.core.IResource, typing_extensions.Protocol):
 
 
 class _IProfilingGroupProxy(
-    jsii.proxy_for(aws_cdk.core.IResource), # type: ignore[misc]
+    jsii.proxy_for(_aws_cdk_core_f4b25747.IResource), # type: ignore[misc]
 ):
     '''IResource represents a Profiling Group.'''
 
@@ -613,8 +627,8 @@ class _IProfilingGroupProxy(
     @jsii.member(jsii_name="grantPublish")
     def grant_publish(
         self,
-        grantee: aws_cdk.aws_iam.IGrantable,
-    ) -> aws_cdk.aws_iam.Grant:
+        grantee: _aws_cdk_aws_iam_940a1ce0.IGrantable,
+    ) -> _aws_cdk_aws_iam_940a1ce0.Grant:
         '''Grant access to publish profiling information to the Profiling Group to the given identity.
 
         This will grant the following permissions:
@@ -625,14 +639,15 @@ class _IProfilingGroupProxy(
         :param grantee: Principal to grant publish rights to.
         '''
         if __debug__:
-            def stub(grantee: aws_cdk.aws_iam.IGrantable) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__b88e8453e918064181c1aecee1bd3f67e3be3f106ccfa35c61d2de14a0beeba1)
             check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
-        return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantPublish", [grantee]))
+        return typing.cast(_aws_cdk_aws_iam_940a1ce0.Grant, jsii.invoke(self, "grantPublish", [grantee]))
 
     @jsii.member(jsii_name="grantRead")
-    def grant_read(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
+    def grant_read(
+        self,
+        grantee: _aws_cdk_aws_iam_940a1ce0.IGrantable,
+    ) -> _aws_cdk_aws_iam_940a1ce0.Grant:
         '''Grant access to read profiling information from the Profiling Group to the given identity.
 
         This will grant the following permissions:
@@ -643,11 +658,9 @@ class _IProfilingGroupProxy(
         :param grantee: Principal to grant read rights to.
         '''
         if __debug__:
-            def stub(grantee: aws_cdk.aws_iam.IGrantable) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__857e490ea8ed611e137f8d741192595357d9fbd8af493fecefa027a9441b3fc6)
             check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
-        return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantRead", [grantee]))
+        return typing.cast(_aws_cdk_aws_iam_940a1ce0.Grant, jsii.invoke(self, "grantRead", [grantee]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
 typing.cast(typing.Any, IProfilingGroup).__jsii_proxy_class__ = lambda : _IProfilingGroupProxy
@@ -655,7 +668,7 @@ typing.cast(typing.Any, IProfilingGroup).__jsii_proxy_class__ = lambda : _IProfi
 
 @jsii.implements(IProfilingGroup)
 class ProfilingGroup(
-    aws_cdk.core.Resource,
+    _aws_cdk_core_f4b25747.Resource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-codeguruprofiler.ProfilingGroup",
 ):
@@ -676,7 +689,7 @@ class ProfilingGroup(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         compute_platform: typing.Optional[ComputePlatform] = None,
@@ -689,15 +702,7 @@ class ProfilingGroup(
         :param profiling_group_name: A name for the profiling group. Default: - automatically generated name.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                compute_platform: typing.Optional[ComputePlatform] = None,
-                profiling_group_name: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__9f73721c21dbd5761dbe85ea68b74337db5ee95895842cc79becdf3ebf80b5e0)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ProfilingGroupProps(
@@ -711,7 +716,7 @@ class ProfilingGroup(
     @builtins.classmethod
     def from_profiling_group_arn(
         cls,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         profiling_group_arn: builtins.str,
     ) -> IProfilingGroup:
@@ -722,13 +727,7 @@ class ProfilingGroup(
         :param profiling_group_arn: Profiling Group ARN.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                profiling_group_arn: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__7ed5b8ed1bb81d6853ec217fb9bd052bbd652fe0f6f31c9f27ee10afe4e5ab1b)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument profiling_group_arn", value=profiling_group_arn, expected_type=type_hints["profiling_group_arn"])
@@ -738,7 +737,7 @@ class ProfilingGroup(
     @builtins.classmethod
     def from_profiling_group_name(
         cls,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         profiling_group_name: builtins.str,
     ) -> IProfilingGroup:
@@ -749,13 +748,7 @@ class ProfilingGroup(
         :param profiling_group_name: Profiling Group Name.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                profiling_group_name: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__6570e1a29cd47f21d0efb3006df51f83531a77b485867312993aecbecf4920f2)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument profiling_group_name", value=profiling_group_name, expected_type=type_hints["profiling_group_name"])
@@ -764,8 +757,8 @@ class ProfilingGroup(
     @jsii.member(jsii_name="grantPublish")
     def grant_publish(
         self,
-        grantee: aws_cdk.aws_iam.IGrantable,
-    ) -> aws_cdk.aws_iam.Grant:
+        grantee: _aws_cdk_aws_iam_940a1ce0.IGrantable,
+    ) -> _aws_cdk_aws_iam_940a1ce0.Grant:
         '''Grant access to publish profiling information to the Profiling Group to the given identity.
 
         This will grant the following permissions:
@@ -776,14 +769,15 @@ class ProfilingGroup(
         :param grantee: Principal to grant publish rights to.
         '''
         if __debug__:
-            def stub(grantee: aws_cdk.aws_iam.IGrantable) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__715e3c0f5162e7f09ed226e552e8e16f1a41229f938c0db122a3e0b441b7f297)
             check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
-        return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantPublish", [grantee]))
+        return typing.cast(_aws_cdk_aws_iam_940a1ce0.Grant, jsii.invoke(self, "grantPublish", [grantee]))
 
     @jsii.member(jsii_name="grantRead")
-    def grant_read(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
+    def grant_read(
+        self,
+        grantee: _aws_cdk_aws_iam_940a1ce0.IGrantable,
+    ) -> _aws_cdk_aws_iam_940a1ce0.Grant:
         '''Grant access to read profiling information from the Profiling Group to the given identity.
 
         This will grant the following permissions:
@@ -794,11 +788,9 @@ class ProfilingGroup(
         :param grantee: Principal to grant read rights to.
         '''
         if __debug__:
-            def stub(grantee: aws_cdk.aws_iam.IGrantable) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__b2bc605fb815f0a8c34f4a8f4fd0712c20779ff807cd5bcf82c063d4778bc7fd)
             check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
-        return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantRead", [grantee]))
+        return typing.cast(_aws_cdk_aws_iam_940a1ce0.Grant, jsii.invoke(self, "grantRead", [grantee]))
 
     @builtins.property
     @jsii.member(jsii_name="profilingGroupArn")
@@ -848,16 +840,10 @@ class ProfilingGroupProps:
             )
         '''
         if __debug__:
-            def stub(
-                *,
-                compute_platform: typing.Optional[ComputePlatform] = None,
-                profiling_group_name: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__d9b7f51223bb1d72f5f58c12cadd72e0fcf5c8c84883fb377edf6a43144c7485)
             check_type(argname="argument compute_platform", value=compute_platform, expected_type=type_hints["compute_platform"])
             check_type(argname="argument profiling_group_name", value=profiling_group_name, expected_type=type_hints["profiling_group_name"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if compute_platform is not None:
             self._values["compute_platform"] = compute_platform
         if profiling_group_name is not None:
@@ -903,3 +889,136 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__f716c140051ab3ab0d85b12915727069b195d1b8b90a71c09337bd86eed52c55(
+    scope: _aws_cdk_core_f4b25747.Construct,
+    id: builtins.str,
+    *,
+    profiling_group_name: builtins.str,
+    agent_permissions: typing.Any = None,
+    anomaly_detection_notification_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnProfilingGroup.ChannelProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
+    compute_platform: typing.Optional[builtins.str] = None,
+    tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__cd8d9915cd249d32e2cca82629c4798ab6b6578ff7e101f1d0fe197015130b43(
+    inspector: _aws_cdk_core_f4b25747.TreeInspector,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b9120857a7ca75673ab928dc634fc0ff341c0a256d3f8e97da5d3d1c50c868af(
+    props: typing.Mapping[builtins.str, typing.Any],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2b8f16257dd8b97675d05722f4c74a89415dfe9dd90c9c69acfa5fb72268e9e3(
+    value: typing.Any,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__827c37a5bbd608aa0ab6c3cd91c24b907ebc73319417390b0a1c6656740f2bb4(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9a8dbd2729ce0a37f9a95dcd047bc3c7c6bbbe1f281e0cefa1ec7a889ad8ac9b(
+    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnProfilingGroup.ChannelProperty]]]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__54bdaa4e19c8380cabfc1afb202043849692b396db8548d3f7e55cd3ce85d369(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__30fe6ae1b3b847041e02a0703afa10fbbab3170e1df4694345a7ef3fdd5b28df(
+    *,
+    principals: typing.Sequence[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5a6c20a5deea4cd71b89d6e657354d122cbb4a3334b43d004333284d685373ea(
+    *,
+    channel_uri: builtins.str,
+    channel_id: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d7ab3f016dc6dd9dc09dbdd386c1dc4b0b32d9e05d5f91674f86042fc33b91f7(
+    *,
+    profiling_group_name: builtins.str,
+    agent_permissions: typing.Any = None,
+    anomaly_detection_notification_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnProfilingGroup.ChannelProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
+    compute_platform: typing.Optional[builtins.str] = None,
+    tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b88e8453e918064181c1aecee1bd3f67e3be3f106ccfa35c61d2de14a0beeba1(
+    grantee: _aws_cdk_aws_iam_940a1ce0.IGrantable,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__857e490ea8ed611e137f8d741192595357d9fbd8af493fecefa027a9441b3fc6(
+    grantee: _aws_cdk_aws_iam_940a1ce0.IGrantable,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9f73721c21dbd5761dbe85ea68b74337db5ee95895842cc79becdf3ebf80b5e0(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    compute_platform: typing.Optional[ComputePlatform] = None,
+    profiling_group_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7ed5b8ed1bb81d6853ec217fb9bd052bbd652fe0f6f31c9f27ee10afe4e5ab1b(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    profiling_group_arn: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6570e1a29cd47f21d0efb3006df51f83531a77b485867312993aecbecf4920f2(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    profiling_group_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__715e3c0f5162e7f09ed226e552e8e16f1a41229f938c0db122a3e0b441b7f297(
+    grantee: _aws_cdk_aws_iam_940a1ce0.IGrantable,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b2bc605fb815f0a8c34f4a8f4fd0712c20779ff807cd5bcf82c063d4778bc7fd(
+    grantee: _aws_cdk_aws_iam_940a1ce0.IGrantable,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d9b7f51223bb1d72f5f58c12cadd72e0fcf5c8c84883fb377edf6a43144c7485(
+    *,
+    compute_platform: typing.Optional[ComputePlatform] = None,
+    profiling_group_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
